package Task::BeLike::TOBYINK::Packaging;

use 5.010;

BEGIN {
	$Task::BeLike::TOBYINK::Packaging::AUTHORITY = 'cpan:TOBYINK';
	$Task::BeLike::TOBYINK::Packaging::VERSION   = '2012.155';
}

__PACKAGE__
__END__

=head1 NAME

Task::BeLike::TOBYINK::Packaging - be like TOBYINK and use these Packaging stuffz

=head1 DESCRIPTION

Task installs the following modules:

=over

=item * Module::Package::RDF

=item * Perl::Version

=item * RT::ClientX::GrabBugs

=back

=head1 SEE ALSO

L<Acme::About::TOBYINK>,
L<Task::BeLike::TOBYINK>.

=head1 AUTHOR

Toby Inkster E<lt>tobyink@cpan.orgE<gt>.

=head1 COPYRIGHT AND LICENCE

This software is copyright (c) 2012 by Toby Inkster.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 DISCLAIMER OF WARRANTIES

THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
